@@ -19,13 +19,15 @@ kdbwselect <- function(x, eval=NULL, neval=NULL, rho=NULL, kernel="epa",
   if (is.null(eval)) {
     if (is.null(neval)) {
       #eval <- unique(x)
-      qseq <- seq(0,1,1/(20+1))
-      eval <- quantile(x, qseq[2:(length(qseq)-1)])
+      #qseq <- seq(0,1,1/(20+1))
+      #eval <- quantile(x, qseq[2:(length(qseq)-1)])
+      eval <- seq(x.min, x.max, length.out=30)
     }
     else {
       #eval <- seq(x.min,x.max,length.out=neval)
-      qseq <- seq(0,1,1/(neval+1))
-      eval <- quantile(x, qseq[2:(length(qseq)-1)])
+      #qseq <- seq(0,1,1/(neval+1))
+      #eval <- quantile(x, qseq[2:(length(qseq)-1)])
+      eval <- seq(x.min, x.max, length.out=neval)
     }
   }
   neval <- length(eval)
